@@ -28,6 +28,7 @@
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
 #include "xsane.h"
+#include "xsane-batch-scan.h"
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
 
@@ -55,12 +56,15 @@ extern SANE_Status xsane_control_option(SANE_Handle handle, SANE_Int option, SAN
 extern int xsane_back_gtk_make_path(size_t max_len, char *filename_ret, const char *prog_name, const char *dir_name,
                                     const char *prefix, const char *dev_name, const char *postfix, int local);
 extern gint xsane_back_gtk_decision(gchar *title, gchar** icon_xpm, gchar *message, gchar *oktext, gchar *rejecttext, int wait);
+extern void xsane_back_gtk_ipc_dialog_callback(gpointer data, gint source, GdkInputCondition cond);
 extern void xsane_back_gtk_message(gchar *title, gchar** icon_xpm, gchar *message, int wait);
 extern void xsane_back_gtk_error(gchar *error_message, int wait);
 extern void xsane_back_gtk_warning(gchar *warning_message, int wait);
 extern void xsane_back_gtk_info(gchar *info_message, int wait);
-extern int xsane_back_gtk_get_filename(const char *label, const char *default_name, size_t max_len, char *filename,
-                                       int show_fileopts, int shorten_path, int hide_file_list);
+extern void xsane_back_gtk_filetype_menu_set_history(GtkWidget *xsane_filetype_option_menu, char *filetype);
+extern GtkWidget *xsane_back_gtk_filetype_menu_new(char *filetype, GtkSignalFunc filetype_callback);
+extern int xsane_back_gtk_get_filename(const char *label, const char *default_name, size_t max_len, char *filename, char **filetype,
+                                       int show_fileopts, int shorten_path, int hide_file_list, int show_filetype_menu);
 
 extern void xsane_back_gtk_sync(void);
 extern void xsane_back_gtk_update_vector(int opt_num, SANE_Int *vector);
@@ -74,6 +78,11 @@ extern void xsane_back_gtk_set_sensitivity(int sensitive);
 extern void xsane_set_sensitivity(SANE_Int sensitivity);
 extern void xsane_back_gtk_destroy_dialog(void);
 extern void xsane_back_gtk_set_option(int opt_num, void *val, SANE_Action action);
+extern int xsane_back_gtk_set_option_double(int option, double value);
+extern int xsane_back_gtk_get_option_double(int option, double *val, SANE_Int *unit);
+extern void xsane_back_gtk_set_option(int opt_num, void *val, SANE_Action action);
+extern void xsane_back_gtk_get_batch_parameters(Batch_Scan_Parameters *parameters, SANE_Int *unit);
+extern void xsane_back_gtk_establish_batch_parameters(Batch_Scan_Parameters *parameters, int panel_rebuild, int set_scanmode, int set_resolution);
 extern GtkWidget *xsane_back_gtk_group_new (GtkWidget *parent, const char * title);
 extern void xsane_back_gtk_button_new(GtkWidget * parent, const char *name, SANE_Word val,
             GSGDialogElement *elem, GtkTooltips *tooltips, const char *desc, SANE_Int settable);
@@ -86,6 +95,6 @@ extern void xsane_back_gtk_text_entry_new(GtkWidget *parent, const char *name, c
                 GSGDialogElement *elem, GtkTooltips *tooltips, const char *desc, SANE_Int settable);
 extern void xsane_back_gtk_push_button_callback(GtkWidget * widget, gpointer data);
 extern const char *xsane_back_gtk_unit_string(SANE_Unit unit);
-void xsane_set_window_icon(GtkWidget *gtk_window, gchar **xpm_d);
+extern void xsane_set_window_icon(GtkWidget *gtk_window, gchar **xpm_d);
 
 #endif
