@@ -51,7 +51,9 @@ Preferences preferences =
   {
        0,		/* xsane-version string */
        0,		/* default path to temporary directory (not defined here) */
+       0,		/* default working_directory */
        0,		/* no default filename */
+       0,		/* no default filetype */
        0137,		/* image umask (permission mask for -rw-r------) */
        0027,		/* directory umask (permission mask for -rwxr-x----) */
        0,		/* no fax project */
@@ -91,16 +93,18 @@ Preferences preferences =
        1,		/* save_devprefs_at_exit */
        1,		/* overwrite_warning */
        1,		/* skip_existing_numbers */
+       0,		/* save_pnm16_as_ascii */
        0,		/* reduce_16bit_to_8bit */
        1,		/* filename_counter_step */
        4,		/* filename_counter_len */
        6,		/* show_range_mode */
        1,		/* tooltips enabled */
-       1,		/* (dont) show histogram */
-       1,		/* (dont) show gamma */
-       1,		/* (dont) show standard options */
-       0,		/* (dont) show advanced options */
-       0,		/* (dont) show resolution list */
+       1,		/* show histogram */
+       1,		/* show gamma */
+       0,		/* don't show batch scan */
+       1,		/* show standard options */
+       0,		/* don`t show advanced options */
+       0,		/* don`t show resolution list */
       10.0,		/* length unit */
        1,		/* main window fixed (1) or scrolled (0) */
        0,		/* preview_own_cmap */
@@ -130,7 +134,7 @@ Preferences preferences =
        1,		/* preselect_scanarea after preview scan */
        1,		/* auto_correct_colors after preview scan */
  GTK_UPDATE_DISCONTINUOUS, /* update policy for gtk frontend sliders */
-       0,		/* psrotate: rotate in postscript mode (landscape) */
+       0,		/* paper_orientation */
        0,		/* preset_area_definitions */
        0,		/* printernr */
        0		/* printerdefinitions */
@@ -148,7 +152,9 @@ desc[] =
   {
     {"xsane-version",			xsane_rc_pref_string,	POFFSET(xsane_version_str)},
     {"tmp-path",			xsane_rc_pref_string,	POFFSET(tmp_path)},
+    {"working-directory",		xsane_rc_pref_string,	POFFSET(working_directory)},
     {"filename",			xsane_rc_pref_string,	POFFSET(filename)},
+    {"filetype",			xsane_rc_pref_string,	POFFSET(filetype)},
     {"image-umask",			xsane_rc_pref_int,	POFFSET(image_umask)},
     {"directory-umask",			xsane_rc_pref_int,	POFFSET(directory_umask)},
     {"fax-project",			xsane_rc_pref_string,	POFFSET(fax_project)},
@@ -188,6 +194,7 @@ desc[] =
     {"save-devprefs-at-exit",		xsane_rc_pref_int,	POFFSET(save_devprefs_at_exit)},
     {"overwrite-warning",		xsane_rc_pref_int,	POFFSET(overwrite_warning)},
     {"skip-existing-numbers",		xsane_rc_pref_int,	POFFSET(skip_existing_numbers)},
+    {"save-pnm16-as-ascii",		xsane_rc_pref_int,	POFFSET( save_pnm16_as_ascii)},
     {"reduce-16bit-to8bit",		xsane_rc_pref_int,	POFFSET(reduce_16bit_to_8bit)},
     {"filename-counter-step",		xsane_rc_pref_int,	POFFSET(filename_counter_step)},
     {"filename-counter-len",		xsane_rc_pref_int,	POFFSET(filename_counter_len)},
@@ -195,6 +202,7 @@ desc[] =
     {"tool-tips",			xsane_rc_pref_int,	POFFSET(tooltips_enabled)},
     {"show-histogram",			xsane_rc_pref_int,	POFFSET(show_histogram)},
     {"show-gamma",			xsane_rc_pref_int,	POFFSET(show_gamma)},
+    {"show-batch-scan",			xsane_rc_pref_int,	POFFSET(show_batch_scan)},
     {"show-standard-options",		xsane_rc_pref_int,	POFFSET(show_standard_options)},
     {"show-advanced-options",		xsane_rc_pref_int,	POFFSET(show_advanced_options)},
     {"show-resolution-list",		xsane_rc_pref_int,	POFFSET(show_resolution_list)},
@@ -227,7 +235,7 @@ desc[] =
     {"preselect-scanarea",		xsane_rc_pref_int,	POFFSET(preselect_scanarea)},
     {"auto-correct-colors",		xsane_rc_pref_int,	POFFSET(auto_correct_colors)},
     {"gtk-update-policy",		xsane_rc_pref_int,	POFFSET(gtk_update_policy)},
-    {"postscript-rotate",		xsane_rc_pref_int,	POFFSET(psrotate)},
+    {"paper-orientation",		xsane_rc_pref_int,	POFFSET(paper_orientation)},
     {"preset-area-definitions",		xsane_rc_pref_int,	POFFSET(preset_area_definitions)},
     {"medium-definitions",		xsane_rc_pref_int,	POFFSET(medium_definitions)},
     {"printernr",			xsane_rc_pref_int,	POFFSET(printernr)},
